Struct Sr
#[repr(transparent)]pub struct Sr(pub u32);Expand description
DCACHE status register.
Tuple Fields
0: u32Implementations
impl Sr
impl Sr
pub const fn bsyendf(&self) -> bool
pub const fn bsyendf(&self) -> bool
full invalidate busy end flag Cleared by writing DCACHE_FCR.CBSYENDF = 1.
pub const fn set_bsyendf(&mut self, val: bool)
pub const fn set_bsyendf(&mut self, val: bool)
full invalidate busy end flag Cleared by writing DCACHE_FCR.CBSYENDF = 1.
pub const fn set_errf(&mut self, val: bool)
pub const fn set_errf(&mut self, val: bool)
cache error flag Cleared by writing DCACHE_FCR.CERRF = 1.
pub const fn set_busycmdf(&mut self, val: bool)
pub const fn set_busycmdf(&mut self, val: bool)
command busy flag.
pub const fn set_cmdendf(&mut self, val: bool)
pub const fn set_cmdendf(&mut self, val: bool)
command end flag Cleared by writing DCACHE_FCR.CCMDENDF = 1.